#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;

#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Created by Elliott Wave from the original NT code. 11/20/2008. Version 1.01 changed StdDev from int to double.
    /// </summary>

	
    [Description("Breakout Pattern Recognittion")]
    public class BreakoutRecognition : Indicator
    {
        #region Variables
        // Wizard generated variables
			private bool alertOnBreakout = true;
            private int bbPeriods = 14; // Default setting for MyInput0
			private double sTDev = 2;
			private int textOffset = 50;
		
			
			private DataSeries bullBreakouts;
			private DataSeries bearBreakouts;
			
		
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
			

			bullBreakouts		=	new DataSeries(this);
			bearBreakouts		=	new DataSeries(this);
			
			
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar < 4) return;
			
/////////////////Breakouts	
			if (Close[0] > Bollinger(sTDev, bbPeriods).Upper[0] && Close[1] > Bollinger(sTDev, bbPeriods).Upper[1] 
				&& Close [2] < Bollinger(sTDev, bbPeriods).Upper[2]
				)
				{
					DrawArrowUp("MyArrowUp"+CurrentBar, 0, Low[0], Color.Lime);
					DrawText("Bull Breakout"+CurrentBar, "Bull Breakout", 0, Low[0]-textOffset* TickSize, Color.Blue);
					bullBreakouts.Set(1);
					
					if (AlertOnBreakout  == true)
					{
						
						Alert("Bull Alert", Priority.High, "BullBreakout", "Alert2.wav", 100000, Color.White, Color.Blue);
					}
					
				}
			else	
				bullBreakouts.Set(0);
				
			if (Close[0] < Bollinger(sTDev, bbPeriods).Lower[0] && Close[1] < Bollinger(sTDev, bbPeriods).Lower[1] 
				&& Close [2] > Bollinger(sTDev, bbPeriods).Lower[2]
				)
				{
					DrawArrowDown("MyArrowDown"+CurrentBar, 0, High[0], Color.Red);
					DrawText("Bear Breakout"+CurrentBar, "Bear Breakout", 0, High[0]+textOffset* TickSize, Color.Red);
					bearBreakouts.Set(1);
					
					if (AlertOnBreakout  == true)
					{
						
						Alert("Bear Alert", Priority.High, "Bear Breakout", "Alert2.wav", 100000, Color.White, Color.Blue);
					}
					
				}
			else
				bearBreakouts.Set(0);	
/////////////////Breakouts	
				 		
		
       }

        #region Properties

	
        [Description("Bolinger Band Period")]
        [Category("Parameters")]
        public int BBPeriods
        {
            get { return bbPeriods; }
            set { bbPeriods = Math.Max(0, value); }
        }
		
		 [Description("Bolinger Band Std Deviation")]
        [Category("Parameters")]
        public double STDev
        {
            get { return sTDev; }
            set { sTDev = Math.Max(0, value); }
        }
		
		[Description("Generates a visual and audible alert on a breakout")]
        [Category("Parameters")]
        public bool AlertOnBreakout
        {
            get { return alertOnBreakout; }
            set { alertOnBreakout = value; }
        }
		
		[Description("Text offset value in ticks")]
        [Category("Visual")]
        public int TextOffset
        {
            get { return textOffset; }
            set { textOffset = value; }
        }
		
		
		[Browsable(false)]
        [XmlIgnore()]
        public DataSeries BullBreakouts
        {
            get 
           { 
                Update();
                return bullBreakouts;
			 
           }
        }
		[Browsable(false)]
        [XmlIgnore()]
        public DataSeries BearBreakouts
        {
            get 
           { 
                Update();
                return bearBreakouts;
			 
           }
        }
		
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private BreakoutRecognition[] cacheBreakoutRecognition = null;

        private static BreakoutRecognition checkBreakoutRecognition = new BreakoutRecognition();

        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        public BreakoutRecognition BreakoutRecognition(bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            return BreakoutRecognition(Input, alertOnBreakout, bBPeriods, sTDev);
        }

        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        public BreakoutRecognition BreakoutRecognition(Data.IDataSeries input, bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            checkBreakoutRecognition.AlertOnBreakout = alertOnBreakout;
            alertOnBreakout = checkBreakoutRecognition.AlertOnBreakout;
            checkBreakoutRecognition.BBPeriods = bBPeriods;
            bBPeriods = checkBreakoutRecognition.BBPeriods;
            checkBreakoutRecognition.STDev = sTDev;
            sTDev = checkBreakoutRecognition.STDev;

            if (cacheBreakoutRecognition != null)
                for (int idx = 0; idx < cacheBreakoutRecognition.Length; idx++)
                    if (cacheBreakoutRecognition[idx].AlertOnBreakout == alertOnBreakout && cacheBreakoutRecognition[idx].BBPeriods == bBPeriods && Math.Abs(cacheBreakoutRecognition[idx].STDev - sTDev) <= double.Epsilon && cacheBreakoutRecognition[idx].EqualsInput(input))
                        return cacheBreakoutRecognition[idx];

            BreakoutRecognition indicator = new BreakoutRecognition();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.AlertOnBreakout = alertOnBreakout;
            indicator.BBPeriods = bBPeriods;
            indicator.STDev = sTDev;
            indicator.SetUp();

            BreakoutRecognition[] tmp = new BreakoutRecognition[cacheBreakoutRecognition == null ? 1 : cacheBreakoutRecognition.Length + 1];
            if (cacheBreakoutRecognition != null)
                cacheBreakoutRecognition.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheBreakoutRecognition = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.BreakoutRecognition BreakoutRecognition(bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            return _indicator.BreakoutRecognition(Input, alertOnBreakout, bBPeriods, sTDev);
        }

        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        public Indicator.BreakoutRecognition BreakoutRecognition(Data.IDataSeries input, bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            return _indicator.BreakoutRecognition(input, alertOnBreakout, bBPeriods, sTDev);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.BreakoutRecognition BreakoutRecognition(bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            return _indicator.BreakoutRecognition(Input, alertOnBreakout, bBPeriods, sTDev);
        }

        /// <summary>
        /// Breakout Pattern Recognittion
        /// </summary>
        /// <returns></returns>
        public Indicator.BreakoutRecognition BreakoutRecognition(Data.IDataSeries input, bool alertOnBreakout, int bBPeriods, double sTDev)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.BreakoutRecognition(input, alertOnBreakout, bBPeriods, sTDev);
        }

    }
}
#endregion
